unit CustomSLOGSnodeVisual;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Controls, Graphics, CustomSLOGSnodeOptForm,
  StdCtrls, ExtCtrls;

type
  TNodeOptForm=class of TCustomSLOGSnodeOptForm;// Sammelklasse

  { TCustomSLOGSNodeVisual }
  TCustomSLOGSNodeVisual=class(TCustomControl)
    private
      OldSize:TPoint;
      FDecor:TBitmap;
      FHighlight: boolean;
      FShapePattern:TBitmap;
      FMouseDownXY:TPoint;
      FDragging:Boolean;
      ANodeOptForm:TCustomSLOGSnodeOptForm;
    protected
      function CorrespondingFormClass:TNodeOptForm; virtual;
      procedure BoundsChanged; override;
      procedure Click; override;
      procedure Paint; override;
    protected
      procedure NodeDecor(ADecor:TBitmap); virtual; abstract; //zeichnen der Oberfläche
      procedure NodeShape(APattern:TBitmap); virtual; abstract; //Komponentenform
    public
      procedure Invalidate; override;
      constructor Create(AOwner: TComponent); override;
      destructor Destroy; override;
    published
      property Color;
  end;



implementation

{ TCustomSLOGSNodeVisual }


procedure TCustomSLOGSNodeVisual.Paint;
begin
  inherited Paint;
  Canvas.Draw(0,0,FDecor);
end;

procedure TCustomSLOGSNodeVisual.Click;
begin
  inherited Click;
  ANodeOptForm:=CorrespondingFormClass.Create(Owner);
  ANodeOptForm.ShowModal;
  ANodeOptForm.Free;
  SetFocus;
end;

procedure TCustomSLOGSNodeVisual.Invalidate;
begin
  inherited Invalidate;
end;

function TCustomSLOGSNodeVisual.CorrespondingFormClass: TNodeOptForm;
begin
  result:=TCustomSLOGSnodeOptForm;
end;

procedure TCustomSLOGSNodeVisual.BoundsChanged;
begin
  inherited BoundsChanged;
  if ((Height=OldSize.Y) and (Width=OldSize.X)) Then exit;
  OldSize:=Point(Width, Height);
  FDecor.Height:=Height;
  FDecor.Width:=Width;
  FShapePattern.Height:=Height;
  FShapePattern.Width:=Width;
  FShapePattern.Canvas.Brush.Color:=clBlack;
  FShapePattern.Canvas.FillRect(0, 0, FShapePattern.Width, FShapePattern.Height);
  FShapePattern.Canvas.Brush.Color:=clWhite;
  NodeDecor(FDecor);
  NodeShape(FShapePattern);
  SetShape(FShapePattern);
  Invalidate;
end;

constructor TCustomSLOGSNodeVisual.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  TabStop:=true;
  FDecor:=TBitmap.Create;
  Color:=$180183;
  FDecor.Canvas.Pen.Color:=clBlack;
  FShapePattern:=TBitmap.Create;
  FShapePattern.Monochrome:=true;
  BoundsChanged;
  OldSize:=Point(-10,-10);
  FMouseDownXY:=Point(-10, -10);
end;

destructor TCustomSLOGSNodeVisual.Destroy;
begin
  FreeAndNil(FDecor);
  FreeAndNil(FShapePattern);
  inherited Destroy;
end;

end.

